@@ -49,7 +49,7 @@ StationDialog::StationDialog(Station *station, QWidget * parent)
 
   /* Update Station Status */
   if (station->freeSlots() == -1) {
-    station->plugin()->update(station);
+    station->plugin()->updateCached(station);
     connect(station->plugin(), SIGNAL(stationsUpdated(const QList < Station * > &)),
 	    this, SLOT(setupWidgets()));
   }
